@@ -167,7 +167,7 @@ class Converter(object):
             # get last not skipped completion and make result from it
             tmp = list(filter(lambda x: not (x.get('skipped', False) or x.get('was_cancelled', False)), d['completions']))
             if len(tmp) > 0:
-                result = sorted(tmp, key=lambda x: x['created_at'], reverse=True)[0]['result']
+                result = sorted(tmp, key=lambda x: x.get('created_at', 0), reverse=True)[0]['result']
             else:
                 return None
             
@@ -177,7 +177,7 @@ class Converter(object):
         inputs = d['data']
         outputs = defaultdict(list)
         for r in result:
-            if r['from_name'] in self._output_tags:
+            if 'from_name' in r and r['from_name'] in self._output_tags:
                 v = deepcopy(r['value'])
                 v['type'] = self._schema[r['from_name']]['type']
                 if 'original_width' in r:
